@@ -1,6 +1,7 @@
 //! HTTP Client
 
 use std::{
+    borrow::Cow,
     collections::VecDeque,
     fmt::Debug,
     future::Future,
@@ -11,6 +12,7 @@ use std::{
     time::{Duration, Instant},
 };
 
+use http::{header::InvalidHeaderValue, HeaderValue, Method as HttpMethod, Uri, Version as HttpVersion};
 use hyper::{
     body::{self, Body},
     client::conn::{http1, http2},
@@ -43,6 +45,12 @@ pub enum HttpClientError {
     /// std::io::Error
     #[error("{0}")]
     Io(#[from] io::Error),
+    /// Errors from http
+    #[error("{0}")]
+    Http(#[from] http::Error),
+    /// Errors from http header
+    #[error("{0}")]
+    InvalidHeaderValue(#[from] InvalidHeaderValue),
 }
 
 #[derive(Clone, Debug)]
@@ -133,7 +141,7 @@ where
     pub async fn send_request(
         &self,
         context: Arc<ServiceContext>,
-        req: Request<B>,
+        mut req: Request<B>,
         balancer: Option<&PingBalancer>,
     ) -> Result<Response<body::Incoming>, HttpClientError> {
         let host = match host_addr(req.uri()) {
@@ -141,15 +149,24 @@ where
             None => panic!("URI missing host: {}", req.uri()),
         };
 
+        // Set Host header if it was missing in the Request
+        {
+            let headers = req.headers_mut();
+            if !headers.contains_key("Host") {
+                let host_value = match host {
+                    Address::DomainNameAddress(ref domain, _) => HeaderValue::from_str(domain)?,
+                    Address::SocketAddress(ref saddr) => HeaderValue::from_str(saddr.ip().to_string().as_str())?,
+                };
+                headers.insert("Host", host_value);
+            }
+        }
+
         // 1. Check if there is an available client
         //
-        // FIXME: If the cached connection is closed unexpectly, this request will fail immediately.
+        // FIXME: If the cached connection is closed unexpectedly, this request will fail immediately.
         if let Some(c) = self.get_cached_connection(&host).await {
             trace!("HTTP client for host: {} taken from cache", host);
-            match self.send_request_conn(host, c, req).await {
-                Ok(o) => return Ok(o),
-                Err(err) => return Err(err.into()),
-            }
+            return self.send_request_conn(host, c, req).await;
         }
 
         // 2. If no. Make a new connection
@@ -158,13 +175,12 @@ where
             None => &Scheme::HTTP,
         };
 
-        let domain = req
-            .uri()
-            .host()
-            .unwrap()
-            .trim_start_matches('[')
-            .trim_start_matches(']');
-        let c = match HttpConnection::connect(context.clone(), scheme, host.clone(), domain, balancer).await {
+        let domain = match host {
+            Address::DomainNameAddress(ref domain, _) => Cow::Borrowed(domain.as_str()),
+            Address::SocketAddress(ref saddr) => Cow::Owned(saddr.ip().to_string()),
+        };
+
+        let c = match HttpConnection::connect(context.clone(), scheme, host.clone(), &domain, balancer).await {
             Ok(c) => c,
             Err(err) => {
                 error!("failed to connect to host: {}, error: {}", host, err);
@@ -172,7 +188,7 @@ where
             }
         };
 
-        self.send_request_conn(host, c, req).await.map_err(Into::into)
+        self.send_request_conn(host, c, req).await
     }
 
     async fn get_cached_connection(&self, host: &Address) -> Option<HttpConnection<B>> {
@@ -196,7 +212,7 @@ where
         host: Address,
         mut c: HttpConnection<B>,
         req: Request<B>,
-    ) -> hyper::Result<Response<body::Incoming>> {
+    ) -> Result<Response<body::Incoming>, HttpClientError> {
         trace!("HTTP making request to host: {}, request: {:?}", host, req);
         let response = c.send_request(req).await?;
         trace!("HTTP received response from host: {}, response: {:?}", host, response);
@@ -298,7 +314,7 @@ where
         let stream = ProxyHttpStream::connect_https(stream, domain).await?;
 
         if stream.negotiated_http2() {
-            // H2 connnection
+            // H2 connection
             let (send_request, connection) = match http2::Builder::new(TokioExecutor)
                 .timer(TokioTimer)
                 .keep_alive_interval(Duration::from_secs(15))
@@ -339,10 +355,45 @@ where
     }
 
     #[inline]
-    pub async fn send_request(&mut self, req: Request<B>) -> hyper::Result<Response<body::Incoming>> {
+    pub async fn send_request(&mut self, mut req: Request<B>) -> Result<Response<body::Incoming>, HttpClientError> {
         match self {
-            HttpConnection::Http1(r) => r.send_request(req).await,
-            HttpConnection::Http2(r) => r.send_request(req).await,
+            HttpConnection::Http1(r) => {
+                if !matches!(
+                    req.version(),
+                    HttpVersion::HTTP_09 | HttpVersion::HTTP_10 | HttpVersion::HTTP_11
+                ) {
+                    trace!(
+                        "HTTP client changed Request.version to HTTP/1.1 from {:?}",
+                        req.version()
+                    );
+
+                    *req.version_mut() = HttpVersion::HTTP_11;
+                }
+
+                // Remove Scheme, Host part from URI
+                if req.method() != HttpMethod::CONNECT
+                    && (req.uri().scheme().is_some() || req.uri().authority().is_some())
+                {
+                    let mut builder = Uri::builder();
+                    if let Some(path_and_query) = req.uri().path_and_query() {
+                        builder = builder.path_and_query(path_and_query.as_str());
+                    } else {
+                        builder = builder.path_and_query("/");
+                    }
+                    *(req.uri_mut()) = builder.build()?;
+                }
+
+                r.send_request(req).await.map_err(Into::into)
+            }
+            HttpConnection::Http2(r) => {
+                if !matches!(req.version(), HttpVersion::HTTP_2) {
+                    trace!("HTTP client changed Request.version to HTTP/2 from {:?}", req.version());
+
+                    *req.version_mut() = HttpVersion::HTTP_2;
+                }
+
+                r.send_request(req).await.map_err(Into::into)
+            }
         }
     }
 
