@@ -123,7 +123,6 @@ impl Context {
     }
 
     /// Resolves DNS address to `SocketAddr`s
-    #[allow(clippy::needless_lifetimes)]
     pub async fn dns_resolve<'a>(&self, addr: &'a str, port: u16) -> io::Result<impl Iterator<Item = SocketAddr> + 'a> {
         self.dns_resolver.resolve(addr, port).await
     }
@@ -143,7 +142,7 @@ impl Context {
         self.replay_policy = replay_policy;
     }
 
-    /// Get policy against replay attach
+    /// Get policy against replay attack
     pub fn replay_attack_policy(&self) -> ReplayAttackPolicy {
         self.replay_policy
     }
