@@ -6,7 +6,7 @@ use std::net::SocketAddr;
 pub use self::sys::uds::{UnixListener, UnixStream};
 pub use self::{
     option::{AcceptOpts, ConnectOpts, TcpSocketOpts},
-    sys::{set_tcp_fastopen, socket_bind_dual_stack},
+    sys::{get_ip_stack_capabilities, set_tcp_fastopen, socket_bind_dual_stack, IpStackCapabilities},
     tcp::{TcpListener, TcpStream},
     udp::UdpSocket,
 };
@@ -46,7 +46,8 @@ impl From<SocketAddr> for AddrFamily {
 /// Check if `SocketAddr` could be used for creating dual-stack sockets
 pub fn is_dual_stack_addr(addr: &SocketAddr) -> bool {
     if let SocketAddr::V6(ref v6) = *addr {
-        v6.ip().is_unspecified()
+        let ip = v6.ip();
+        ip.is_unspecified() || ip.to_ipv4_mapped().is_some()
     } else {
         false
     }
