@@ -87,7 +87,7 @@ where
 
     let sock = unsafe { Socket::from_raw_socket(handle) };
     let result = socket_bind_dual_stack_inner(&sock, addr, ipv6_only);
-    sock.into_raw_socket();
+    let _ = sock.into_raw_socket();
 
     result
 }
