@@ -50,10 +50,12 @@
 use std::time::Duration;
 
 pub use self::proxy_socket::ProxySocket;
+pub use compat::{DatagramReceive, DatagramReceiveExt, DatagramSend, DatagramSendExt, DatagramSocket};
 
 mod aead;
 #[cfg(feature = "aead-cipher-2022")]
 mod aead_2022;
+mod compat;
 pub mod crypto_io;
 pub mod options;
 pub mod proxy_socket;
